.. _measure:

============================
Measuring Spatial Inequality
============================

.. toctree::
   :maxdepth: 1

	      
   Gini Index <gini.ipynb>
   Theil Index <theil.ipynb>
   Wolfson Index <wolfson.ipynb>

